@@ -1,5 +1,6 @@
 /*
- * Copyright (c) 1997  Motoyuki Kasahara
+ * Copyright (c) 1997, 2000, 01  
+ *    Motoyuki Kasahara
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -12,8 +13,8 @@
  * GNU General Public License for more details.
  */
 
-#ifndef WRITEALL_H
-#define WRITEALL_H
+#ifndef IOALL_H
+#define IOALL_H
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -24,11 +25,13 @@
  * Function declarations.
  */
 #ifdef __STDC__
-ssize_t read_all(int, void *, size_t nbyte);
-ssize_t write_all(int, const void *, size_t nbyte);
+ssize_t read_all(int, void *, size_t);
+ssize_t write_all(int, const void *, size_t);
+ssize_t write_string_all(int, const void *);
 #else /* not __STDC__ */
 ssize_t read_all();
 ssize_t write_all();
+ssize_t write_string_all();
 #endif /* not __STDC__ */
 
-#endif /* not WRITEALL_H */
+#endif /* not IOALL_H */
